==> windmill_api-1.527.0.tar.gz: windmill_api-1.527.0/windmill_api/models/create_kafka_trigger_json_body_retry.py <==
from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.create_kafka_trigger_json_body_retry_constant import CreateKafkaTriggerJsonBodyRetryConstant
    from ..models.create_kafka_trigger_json_body_retry_exponential import CreateKafkaTriggerJsonBodyRetryExponential


T = TypeVar("T", bound="CreateKafkaTriggerJsonBodyRetry")


@_attrs_define
class CreateKafkaTriggerJsonBodyRetry:
    """
    Attributes:
        constant (Union[Unset, CreateKafkaTriggerJsonBodyRetryConstant]):
        exponential (Union[Unset, CreateKafkaTriggerJsonBodyRetryExponential]):
    """

    constant: Union[Unset, "CreateKafkaTriggerJsonBodyRetryConstant"] = UNSET
    exponential: Union[Unset, "CreateKafkaTriggerJsonBodyRetryExponential"] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        constant: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.constant, Unset):
            constant = self.constant.to_dict()

        exponential: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.exponential, Unset):
            exponential = self.exponential.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if constant is not UNSET:
            field_dict["constant"] = constant
        if exponential is not UNSET:
            field_dict["exponential"] = exponential

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.create_kafka_trigger_json_body_retry_constant import CreateKafkaTriggerJsonBodyRetryConstant
        from ..models.create_kafka_trigger_json_body_retry_exponential import CreateKafkaTriggerJsonBodyRetryExponential

        d = src_dict.copy()
        _constant = d.pop("constant", UNSET)
        constant: Union[Unset, CreateKafkaTriggerJsonBodyRetryConstant]
        if isinstance(_constant, Unset):
            constant = UNSET
        else:
            constant = CreateKafkaTriggerJsonBodyRetryConstant.from_dict(_constant)

        _exponential = d.pop("exponential", UNSET)
        exponential: Union[Unset, CreateKafkaTriggerJsonBodyRetryExponential]
        if isinstance(_exponential, Unset):
            exponential = UNSET
        else:
            exponential = CreateKafkaTriggerJsonBodyRetryExponential.from_dict(_exponential)

        create_kafka_trigger_json_body_retry = cls(
            constant=constant,
            exponential=exponential,
        )

        create_kafka_trigger_json_body_retry.additional_properties = d
        return create_kafka_trigger_json_body_retry

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> windmill_api-1.580.0.tar.gz: windmill_api-1.580.0/windmill_api/models/create_kafka_trigger_json_body_retry.py <==
from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.create_kafka_trigger_json_body_retry_constant import CreateKafkaTriggerJsonBodyRetryConstant
    from ..models.create_kafka_trigger_json_body_retry_exponential import CreateKafkaTriggerJsonBodyRetryExponential
    from ..models.create_kafka_trigger_json_body_retry_retry_if import CreateKafkaTriggerJsonBodyRetryRetryIf


T = TypeVar("T", bound="CreateKafkaTriggerJsonBodyRetry")


@_attrs_define
class CreateKafkaTriggerJsonBodyRetry:
    """
    Attributes:
        constant (Union[Unset, CreateKafkaTriggerJsonBodyRetryConstant]):
        exponential (Union[Unset, CreateKafkaTriggerJsonBodyRetryExponential]):
        retry_if (Union[Unset, CreateKafkaTriggerJsonBodyRetryRetryIf]):
    """

    constant: Union[Unset, "CreateKafkaTriggerJsonBodyRetryConstant"] = UNSET
    exponential: Union[Unset, "CreateKafkaTriggerJsonBodyRetryExponential"] = UNSET
    retry_if: Union[Unset, "CreateKafkaTriggerJsonBodyRetryRetryIf"] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        constant: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.constant, Unset):
            constant = self.constant.to_dict()

        exponential: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.exponential, Unset):
            exponential = self.exponential.to_dict()

        retry_if: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.retry_if, Unset):
            retry_if = self.retry_if.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if constant is not UNSET:
            field_dict["constant"] = constant
        if exponential is not UNSET:
            field_dict["exponential"] = exponential
        if retry_if is not UNSET:
            field_dict["retry_if"] = retry_if

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.create_kafka_trigger_json_body_retry_constant import CreateKafkaTriggerJsonBodyRetryConstant
        from ..models.create_kafka_trigger_json_body_retry_exponential import CreateKafkaTriggerJsonBodyRetryExponential
        from ..models.create_kafka_trigger_json_body_retry_retry_if import CreateKafkaTriggerJsonBodyRetryRetryIf

        d = src_dict.copy()
        _constant = d.pop("constant", UNSET)
        constant: Union[Unset, CreateKafkaTriggerJsonBodyRetryConstant]
        if isinstance(_constant, Unset):
            constant = UNSET
        else:
            constant = CreateKafkaTriggerJsonBodyRetryConstant.from_dict(_constant)

        _exponential = d.pop("exponential", UNSET)
        exponential: Union[Unset, CreateKafkaTriggerJsonBodyRetryExponential]
        if isinstance(_exponential, Unset):
            exponential = UNSET
        else:
            exponential = CreateKafkaTriggerJsonBodyRetryExponential.from_dict(_exponential)

        _retry_if = d.pop("retry_if", UNSET)
        retry_if: Union[Unset, CreateKafkaTriggerJsonBodyRetryRetryIf]
        if isinstance(_retry_if, Unset):
            retry_if = UNSET
        else:
            retry_if = CreateKafkaTriggerJsonBodyRetryRetryIf.from_dict(_retry_if)

        create_kafka_trigger_json_body_retry = cls(
            constant=constant,
            exponential=exponential,
            retry_if=retry_if,
        )

        create_kafka_trigger_json_body_retry.additional_properties = d
        return create_kafka_trigger_json_body_retry

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
